# fitdist - Probability density fitting.

[![Python](https://img.shields.io/pypi/pyversions/fitdist)](https://img.shields.io/pypi/pyversions/fitdist)
[![PyPI Version](https://img.shields.io/pypi/v/fitdist)](https://pypi.org/project/fitdist/)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/erdogant/distfit/blob/master/LICENSE)
[![Github Forks](https://img.shields.io/github/forks/erdogant/distfit.svg)](https://github.com/erdogant/distfit/network)
[![GitHub Open Issues](https://img.shields.io/github/issues/erdogant/distfit.svg)](https://github.com/erdogant/distfit/issues)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)
[![Downloads](https://pepy.tech/badge/distfit/month)](https://pepy.tech/project/fitdist)
[![Downloads](https://pepy.tech/badge/distfit)](https://pepy.tech/project/fitdist)
[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/erdogant/distfit/blob/master/notebooks/distfit.ipynb)
[![DOI](https://zenodo.org/badge/231843440.svg)](https://zenodo.org/badge/latestdoi/231843440)
[![Sphinx](https://img.shields.io/badge/Sphinx-Docs-Green)](https://erdogant.github.io/distfit/)

* ``fitdist`` is Python package that originates from ``distfit`` library.
* More information can be found [at the distfit library](https://github.com/erdogant/distfit)

### Maintainers
* Erdogan Taskesen, github: [erdogant](https://github.com/erdogant)

### Licence
See [LICENSE](LICENSE) for details.

<a href="https://www.buymeacoffee.com/erdogant"><img src="https://img.buymeacoffee.com/button-api/?text=Buy me a coffee&emoji=&slug=erdogant&button_colour=FFDD00&font_colour=000000&font_family=Cookie&outline_colour=000000&coffee_colour=ffffff" /></a>
